summaryrefslogtreecommitdiff
path: root/chef-config/lib/chef-config/config.rb
diff options
context:
space:
mode:
Diffstat (limited to 'chef-config/lib/chef-config/config.rb')
-rw-r--r--chef-config/lib/chef-config/config.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/chef-config/lib/chef-config/config.rb b/chef-config/lib/chef-config/config.rb
index 6a028e9564..4e9355192a 100644
--- a/chef-config/lib/chef-config/config.rb
+++ b/chef-config/lib/chef-config/config.rb
@@ -271,8 +271,8 @@ module ChefConfig
# Using `force_logger` causes chef to default to logger output when STDOUT is a tty
default :force_logger, false
- # Using 'always_stream_output' will have Chef always stream the execute output
- default :always_stream_output, false
+ # Using 'stream_execute_output' will have Chef always stream the execute output
+ default :stream_execute_output, false
default :http_retry_count, 5
default :http_retry_delay, 5